@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: torrent-cell-renderer.c 12827 2011-09-01 22:49:35Z jordan $
+ * $Id: torrent-cell-renderer.c 13388 2012-07-14 19:26:55Z jordan $
  */
 
 #include <gtk/gtk.h>
@@ -362,18 +362,7 @@ gtr_cell_renderer_get_preferred_size( GtkCellRenderer  * renderer,
                                       GtkRequisition   * minimum_size,
                                       GtkRequisition   * natural_size )
 {
-#if GTK_CHECK_VERSION( 3,0,0 )
-
     gtk_cell_renderer_get_preferred_size( renderer, widget, minimum_size, natural_size );
-
-#else
-
-    GtkRequisition r;
-    gtk_cell_renderer_get_size( renderer, widget, NULL, NULL, NULL, &r.width, &r.height );
-    if( minimum_size ) *minimum_size = r;
-    if( natural_size ) *natural_size = r;
-
-#endif
 }
 
 static void
@@ -480,11 +469,7 @@ get_size_full( TorrentCellRenderer * cell,
 static void
 torrent_cell_renderer_get_size( GtkCellRenderer     * cell,
                                 GtkWidget           * widget,
-#if GTK_CHECK_VERSION( 3,0,0 )
                                 const GdkRectangle  * cell_area,
-#else
-                                GdkRectangle        * cell_area,
-#endif
                                 gint                * x_offset,
                                 gint                * y_offset,
                                 gint                * width,
@@ -519,19 +504,12 @@ torrent_cell_renderer_get_size( GtkCellRenderer     * cell,
     }
 }
 
-#if GTK_CHECK_VERSION( 3,0,0 )
-    typedef GdkRGBA GtrColor;
-    #define FOREGROUND_COLOR_KEY "foreground-rgba"
-#else
-    typedef GdkColor GtrColor;
-    #define FOREGROUND_COLOR_KEY "foreground-gdk"
-#endif
+typedef GdkRGBA GtrColor;
+#define FOREGROUND_COLOR_KEY "foreground-rgba"
 
 static void
 get_text_color( GtkWidget * w, const tr_stat * st, GtrColor * setme )
 {
-#if GTK_CHECK_VERSION( 3,0,0 )
-
     static const GdkRGBA red = { 1.0, 0, 0, 0 };
     if( st->error )
         *setme = red;
@@ -539,18 +517,6 @@ get_text_color( GtkWidget * w, const tr_stat * st, GtrColor * setme )
         gtk_style_context_get_color( gtk_widget_get_style_context( w ), GTK_STATE_FLAG_INSENSITIVE, setme );
     else
         gtk_style_context_get_color( gtk_widget_get_style_context( w ), GTK_STATE_FLAG_NORMAL, setme );
-
-#else
-
-    static const GdkColor red = { 0, 65535, 0, 0 };
-    if( st->error )
-        *setme = red;
-    else if( st->activity == TR_STATUS_STOPPED )
-        *setme = gtk_widget_get_style(w)->text[GTK_STATE_INSENSITIVE];
-    else
-        *setme = gtk_widget_get_style(w)->text[GTK_STATE_NORMAL];
-
-#endif
 }
 
 
@@ -573,11 +539,7 @@ get_percent_done( const tr_torrent * tor, const tr_stat * st, bool * seed )
     return d;
 }
 
-#if GTK_CHECK_VERSION( 3,0,0 )
-    typedef cairo_t GtrDrawable;
-#else
-    typedef GdkDrawable GtrDrawable;
-#endif
+typedef cairo_t GtrDrawable;
 
 static void
 gtr_cell_renderer_render( GtkCellRenderer       * renderer,
@@ -586,11 +548,7 @@ gtr_cell_renderer_render( GtkCellRenderer       * renderer,
                           const GdkRectangle    * area,
                           GtkCellRendererState    flags)
 {
-#if GTK_CHECK_VERSION( 3,0,0 )
     gtk_cell_renderer_render( renderer, drawable, widget, area, area, flags );
-#else
-    gtk_cell_renderer_render( renderer, drawable, widget, area, area, area, flags );
-#endif
 }
 
 static void
@@ -786,14 +744,8 @@ static void
 torrent_cell_renderer_render( GtkCellRenderer       * cell,
                               GtrDrawable           * window,
                               GtkWidget             * widget,
-#if GTK_CHECK_VERSION( 3,0,0 )
                               const GdkRectangle    * background_area,
                               const GdkRectangle    * cell_area,
-#else
-                              GdkRectangle          * background_area,
-                              GdkRectangle          * cell_area,
-                              GdkRectangle          * expose_area UNUSED,
-#endif
                               GtkCellRendererState    flags )
 {
     TorrentCellRenderer * self = TORRENT_CELL_RENDERER( cell );
