@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: PrefsController.m 13352 2012-06-18 01:33:27Z livings124 $
+ * $Id: PrefsController.m 13380 2012-07-07 17:58:52Z livings124 $
  *
  * Copyright (c) 2005-2012 Transmission authors and contributors
  *
@@ -61,6 +61,8 @@
 
 - (void) setPrefView: (id) sender;
 
+- (void) updateGrowlButton;
+
 - (void) setKeychainPassword: (const char *) password forService: (const char *) service username: (const char *) username;
 
 @end
@@ -175,19 +177,8 @@
     
     [self setPrefView: nil];
     
-    if ([GrowlApplicationBridge isGrowlRunning])
-    {
-        [fBuiltInGrowlButton setHidden: YES];
-        [fGrowlAppButton setHidden: NO];
-#warning remove NO
-        [fGrowlAppButton setEnabled:NO && [GrowlApplicationBridge isGrowlURLSchemeAvailable]];
-    }
-    else
-    {
-        [fBuiltInGrowlButton setHidden: NO];
-        [fGrowlAppButton setHidden: YES];
-        [fBuiltInGrowlButton setState: [fDefaults boolForKey: @"DisplayNotifications"]];
-    }
+    //make sure proper notification settings are shown
+    [self updateGrowlButton];
     
     //set download folder
     [fFolderPopUp selectItemAtIndex: [fDefaults boolForKey: @"DownloadLocationConstant"] ? DOWNLOAD_FOLDER : DOWNLOAD_TORRENT];
@@ -338,6 +329,12 @@
     return [self toolbarAllowedItemIdentifiers: toolbar];
 }
 
+- (void) windowDidBecomeMain: (NSNotification *) notification
+{
+    //this is a good place to see if Growl was quit/launched
+    [self updateGrowlButton];
+}
+
 + (void) restoreWindowWithIdentifier: (NSString *) identifier state: (NSCoder *) state completionHandler: (void (^)(NSWindow *, NSError *)) completionHandler
 {
     NSWindow * window = [[(Controller *)[NSApp delegate] prefsController] window];
@@ -1453,6 +1450,23 @@
     }
 }
 
+- (void) updateGrowlButton
+{
+    if ([GrowlApplicationBridge isGrowlRunning])
+    {
+        [fBuiltInGrowlButton setHidden: YES];
+        [fGrowlAppButton setHidden: NO];
+#warning remove NO
+        [fGrowlAppButton setEnabled:NO && [GrowlApplicationBridge isGrowlURLSchemeAvailable]];
+    }
+    else
+    {
+        [fBuiltInGrowlButton setHidden: NO];
+        [fGrowlAppButton setHidden: YES];
+        [fBuiltInGrowlButton setState: [fDefaults boolForKey: @"DisplayNotifications"]];
+    }
+}
+
 - (void) setKeychainPassword: (const char *) password forService: (const char *) service username: (const char *) username
 {
     SecKeychainItemRef item = NULL;
